@@ -4,12 +4,15 @@
 
 use v5.14;
 
+use strict;
+use warnings;
+
 use lib 'lib', '../lib';
 
-my $domain  = $ARGV[0] || 'example.com';
+my $domain = $ARGV[0]  || 'example.com';
 my $service = $ARGV[1] || 80;
-my $proto   = $ARGV[2] || 'tcp';
-my $family  = $ARGV[3] || 0;
+my $proto = $ARGV[2]   || 'tcp';
+my $family = $ARGV[3]  || 0;
 
 require AnyEvent::DNS::EtcHosts;
 
@@ -29,7 +32,7 @@ say 'Disabled AnyEvent::DNS::EtcHosts';
     $cv->recv;
 }
 
-say;
+say '';
 say 'Enabled AnyEvent::DNS::EtcHosts';
 
 {
@@ -45,7 +48,7 @@ say 'Enabled AnyEvent::DNS::EtcHosts';
     $cv->recv;
 }
 
-say;
+say '';
 say 'Disabled AnyEvent::DNS::EtcHosts';
 
 {
@@ -58,4 +61,3 @@ say 'Disabled AnyEvent::DNS::EtcHosts';
 
     $cv->recv;
 }
-
