@@ -4,14 +4,17 @@
 
 use v5.14;
 
+use strict;
+use warnings;
+
 use lib 'lib', '../lib';
 
-my $domain  = $ARGV[0] || 'example.com';
+my $domain = $ARGV[0]  || 'example.com';
 my $service = $ARGV[1] || 80;
-my $proto   = $ARGV[2] || 'tcp';
-my $family  = $ARGV[3] || 0;
+my $proto = $ARGV[2]   || 'tcp';
+my $family = $ARGV[3]  || 0;
 
-use if $ENV{PERL_ANYEVENT_DNS} eq 'EtcHosts' || ! $ENV{PERL_ANYEVENT_DNS}, 'AnyEvent::DNS::EtcHosts';
+use if ($ENV{PERL_ANYEVENT_DNS} || '') eq 'EtcHosts' || !$ENV{PERL_ANYEVENT_DNS}, 'AnyEvent::DNS::EtcHosts';
 use AnyEvent::Socket;
 use Socket;
 
